@@ -1,22 +1,22 @@
 /*
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2006 - INRIA - Allan CORNET
- * 
+ *
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
- * are also available at    
+ * are also available at
  * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
  *
  */
 #ifndef __GW_CORE__
 #define __GW_CORE__
-/*--------------------------------------------------------------------------*/ 
+/*--------------------------------------------------------------------------*/
 #include "machine.h"
 #include "api_scilab.h"
-/*--------------------------------------------------------------------------*/ 
+/*--------------------------------------------------------------------------*/
 int gw_core(void);
-/*--------------------------------------------------------------------------*/ 
+/*--------------------------------------------------------------------------*/
 int C2F(sci_debug)(char *fname,unsigned long fname_len);
 int C2F(sci_who)(char *fname,unsigned long fname_len);
 int C2F(sci_warning)(char *fname,unsigned long fname_len);
@@ -57,7 +57,7 @@ int C2F(sci_isglobal)(char *fname,unsigned long fname_len);
 int C2F(sci_gstacksize)(char *fname,unsigned long fname_len);
 int C2F(sci_intppty)(char *fname,unsigned long fname_len);
 int C2F(sci_lasterror)(char *fname,unsigned long fname_len);
-int C2F(sci_getversion)(char *fname,unsigned long fname_len);
+int sci_getversion(char *fname,unsigned long fname_len);
 int C2F(sci_macr2tree)(char *fname,unsigned long fname_len);
 int C2F(sci_getos)(char *fname,unsigned long fname_len);
 int C2F(sci_banner)(char *fname,unsigned long fname_len);
@@ -70,13 +70,12 @@ int C2F(sci_with_module)(char *fname,unsigned long fname_len);
 int C2F(sci_islittleendian)(char *fname,unsigned long fname_len);
 int C2F(sci_getscilabmode)(char *fname,unsigned long fname_len);
 int C2F(sci_librarieslist)(char *fname,unsigned long fname_len);
-int C2F(sci_libraryinfo)(char *fname,unsigned long fname_len);
 int C2F(sci_getvariablesonstack)(char *fname,unsigned long fname_len);
 int C2F(sci_getdebuginfo)(char *fname,unsigned long fname_len);
 int C2F(sci_readgateway)(char *fname,unsigned long fname_len);
 int C2F(sci_exit)(char *fname,unsigned long fname_len);
 int C2F(sci_comp)(char *fname,unsigned long fname_len);
-/*--------------------------------------------------------------------------*/ 
+/*--------------------------------------------------------------------------*/
 #endif /*  __GW_CORE__ */
 /*--------------------------------------------------------------------------*/
 
