@@ -25,6 +25,7 @@
 #include "cvstr.h"
 #include "localization.h"
 #include "Scierror.h"
+#include "do_error_number.h"
 #include "code2str.h"
 #include "elementary_functions.h"
 #include "MALLOC.h"
@@ -605,29 +606,26 @@ int Name2where(char *namex)
  *             since it can be wrong (ex when name is transmited
  *             by fort (intfort : function )
  *----------------------------------------------------------------*/
-int C2F(str2name)(char *namex, int *id, unsigned long name_len)
+int C2F(str2name)(const char *namex, int *id, unsigned long name_len)
 {
 	int ix = 0;
-	int lon = 0;
+    int i = 0;
+	char* temp = 0;
 
-	for (ix = 0 ; ix < (int)  name_len ; ix++ )
-	{
-		if ( namex[ix] == '\0') break;
-		lon++;
-	}
+    /* initialize id array */
+    for (i = 0; i < nsiz;i++) id[i] = 0;
 
-	lon = (int)strlen(namex);
-	/* remove blanks in namex */
-	for (ix = 0; ix < lon; ix++)
-	{
-		if ( namex[ix] == ' ')
-		{
-			namex[ix] = '\0';
-			lon = (int)strlen(namex);
-			break;
-		}
-	}
-	C2F(cvname)(id, namex, &cx0, lon);
+	for (ix = 0; namex[ix] != ' ' && namex[ix] != '\0'; ix++);
+      
+	temp = (char*)MALLOC((ix + 1) * sizeof(char) );
+    if (temp)
+    {
+	    memcpy(temp, namex, ix);
+	    temp[ix] = '\0';
+        /* cx0 = 0 convert name to ID */
+	    C2F(cvname)(id, temp, &cx0, ix);
+        FREE(temp);
+    }
 	return 0;
 }
 /*----------------------------------------------------------------
@@ -1102,7 +1100,7 @@ int GetDimFromVar(int _iVarNum, int _iNum/*Oo*/, int* _piVal)
 	{
 		if(iIsComplex(_iVarNum))
 		{
-			Error(89);
+			SciError(89);
 			return _iNum;
 		}
 		GetRhsVar(_iVarNum, MATRIX_OF_DOUBLE_DATATYPE, &iRows, &iCols, &iRealData);
@@ -1119,7 +1117,7 @@ int GetDimFromVar(int _iVarNum, int _iNum/*Oo*/, int* _piVal)
 		GetRhsVar(_iVarNum, MATRIX_OF_INTEGER_DATATYPE, &iRows, &iCols, &iRealData);
 		if(iRows * iCols != 1)
 		{
-			Error(89);
+			SciError(89);
 			return _iNum;
 		}
 		iRows = 1;
@@ -1129,7 +1127,7 @@ int GetDimFromVar(int _iVarNum, int _iNum/*Oo*/, int* _piVal)
 	}
 	else
 	{
-		Error(89);
+		SciError(89);
 		return _iNum;
 	}
 	return 0;
@@ -1242,13 +1240,13 @@ int iGetOrient(int _iVal)
 	}
 	else
 	{
-		Error(44);
+		SciError(44);
 		return -2;
 	}
 
 	if(iRows != 1 || iCols != 1)
 	{
-		Error(89);
+		SciError(89);
 		return -2;
 	}
 
@@ -1268,7 +1266,7 @@ int iGetOrient(int _iVal)
 	}
 	else
 	{
-		Error(44);
+		SciError(44);
 		return -2;
 	}
 	return iMode;
@@ -1972,13 +1970,13 @@ int iGetStringFromPointer(int* _piAddr, int *_piRows, int *_piCols, int *_piLen,
 	return 0;
 }
 
-void vGetPointerFromDoubleComplex(doublecomplex *_poComplex, int _iSize, double *_pdblReal, double *_pdblImg)
+void vGetPointerFromDoubleComplex(const doublecomplex *_poComplex, int _iSize, double *_pdblReal, double *_pdblImg)
 {
 
 	int iTwo	= 2;
 	int iOne	= 1;
-	double *pReal = &_poComplex[0].r;
-	double *pImg = &_poComplex[0].i;
+	double *pReal = (double*)&_poComplex[0].r;
+	double *pImg = (double*)&_poComplex[0].i;
 
 	if(_pdblReal != NULL && _pdblImg != NULL)
 	{
