@@ -14,7 +14,7 @@
 /*--------------------------------------------------------------------------*/
 extern int C2F(intreal)(int *id);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_real)(char *fname,unsigned long fname_len)
+int sci_real(char *fname,unsigned long fname_len)
 {
 	static int id[6];
 	C2F(intreal)(id);
