@@ -23,13 +23,14 @@
 #include "returnProperty.h"
 #include "Scierror.h"
 #include "localization.h"
+#include "HandleManagement.h"
 
 /*------------------------------------------------------------------------*/
 int get_title_property( sciPointObj * pobj )
 {
   if ( sciGetEntityType(pobj) != SCI_SUBWIN )
   {
-    Scierror(999, _("%s property does not exist for this handle.\n"), "title") ;
+    Scierror(999, _("'%s' property does not exist for this handle.\n"), "title") ;
     return -1 ;
   }
   return sciReturnHandle( sciGetHandle( pSUBWIN_FEATURE(pobj)->mon_title ) ) ;
