@@ -12,7 +12,7 @@
 
 #ifndef __SET_UICONTROL_FOTNANGLE_H__
 #define __SET_UICONTROL_FONTANGLE_H__
-
+#include "dynlib_gui.h"
 #include "ObjectStructure.h"
 
 /**
@@ -25,6 +25,6 @@
  * @param nbCol number of columns of the value on stack
  * @return true if the font angle property set has been correcty done
  */
-int SetUicontrolFontAngle(sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol);
+GUI_IMPEXP int SetUicontrolFontAngle(sciPointObj * pobj, size_t stackPointer, int valueType, int nbRow, int nbCol);
 
 #endif /* __SET_UICONTROL_FOTNANGLE_H__ */
