@@ -2,6 +2,7 @@
  * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
  * Copyright (C) 2007 - INRIA - Allan CORNET
  * Copyright (C) 2007 - INRIA - Vincent COUVERT
+ * Copyright (C) 2010 - DIGITEO - Yann COLLETTE
  *
  * This file must be used under the terms of the CeCILL.
  * This source file is licensed as described in the file COPYING, which
@@ -37,7 +38,7 @@
 #include "SetUicontrolPosition.h"
 #include "freeArrayOfString.h"
 /*--------------------------------------------------------------------------*/
-#define NBPROPERTIES 26
+#define NBPROPERTIES 27
 #define MAXPROPERTYNAMELENGTH 20
 /*--------------------------------------------------------------------------*/
 int sci_uicontrol(char *fname, unsigned long fname_len)
@@ -63,12 +64,11 @@ int sci_uicontrol(char *fname, unsigned long fname_len)
 
   /* @TODO remove this crappy initialization */
   /* DO NOT CHANGE ORDER !! */
-  char propertiesNames[NBPROPERTIES][MAXPROPERTYNAMELENGTH] = {"style", "parent", "backgroundcolor", "foregroundcolor","string", "units", "fontweight", "min", "max", "tag", "position", "relief", "horizontalalignment", "verticalalignment", "sliderstep", "fontname", "callback", "fontangle", "fontunits", "fontsize", "listboxtop", "user_data", "value", "userdata", "visible", "enable"};
+  char propertiesNames[NBPROPERTIES][MAXPROPERTYNAMELENGTH] = {"style", "parent", "backgroundcolor", "foregroundcolor","string", "units", "fontweight", "min", "max", "tag", "position", "relief", "horizontalalignment", "verticalalignment", "sliderstep", "fontname", "callback", "fontangle", "fontunits", "fontsize", "listboxtop", "user_data", "value", "userdata", "visible", "enable", "callback_type"};
   int *propertiesValuesIndices = NULL;
-
+  int lw = 0;
   char *propertyPart = NULL;
 
-  //CheckRhs(2,2);
   CheckLhs(0,1);
 
   if (Rhs==0)
@@ -88,7 +88,8 @@ int sci_uicontrol(char *fname, unsigned long fname_len)
 
       if (VarType(1) != sci_handles)
         {
-          Scierror(999,_("%s: Wrong type for input argument #%d: A graphic handle expected.\n"),fname, 1);
+          lw = 1 + Top - Rhs;
+          C2F(overload)(&lw,"uicontrol",9);
           return FALSE;
         }
       else /* Get parent ID */
@@ -136,6 +137,13 @@ int sci_uicontrol(char *fname, unsigned long fname_len)
     }
   else
     {
+      if ((VarType(1) != sci_handles) && (VarType(1) != sci_strings))
+        {
+          lw = 1 + Top - Rhs;
+          C2F(overload)(&lw,"uicontrol",9);
+          return FALSE;
+        }
+
       /* Allocate memory to store the position of properties in uicontrol call */
       if((propertiesValuesIndices = (int*)MALLOC(sizeof(int)*NBPROPERTIES))==NULL)
         {
@@ -255,6 +263,7 @@ int sci_uicontrol(char *fname, unsigned long fname_len)
                         {
                           propertiesValuesIndices[k] = inputIndex+1; /* Position of value for property */
                           found = 1;
+                          break;
                         }
                     }
                 }
@@ -295,7 +304,7 @@ int sci_uicontrol(char *fname, unsigned long fname_len)
       /* If no parent given then the current figure is the parent */
       if(propertiesValuesIndices[1]==NOT_FOUND)
         {
-					sciPointObj * graphicObject = sciGetPointerFromHandle(GraphicHandle);
+          sciPointObj * graphicObject = sciGetPointerFromHandle(GraphicHandle);
           /* Set the parent */
            switch(pUICONTROL_FEATURE(graphicObject)->style)
             {
