@@ -19,7 +19,7 @@ extern "C"
 #include "MALLOC.h"
 #include "sciprint.h"
 #include "Scierror.h"
-#include "../../../fileio/includes/FileExist.h"
+#include "FileExist.h"
 #include "IsAScalar.h"
 #include "freeArrayOfString.h"
 #include "localization.h"
