@@ -16,7 +16,7 @@
 #include "stack-c.h"
 #include "HistoryManager.h"
 /*--------------------------------------------------------------------------*/
-int C2F(sci_displayhistory)(char *fname,unsigned long fname_len)
+int sci_displayhistory(char *fname,unsigned long fname_len)
 {
 	displayScilabHistory();
 	LhsVar(1) = 0;
