@@ -16,13 +16,14 @@
 #define __CATCHIFJAVAEXCEPTION_H__
 
 #include "BOOL.h" /* BOOL */
+#include "dynlib_jvm.h"
 
 /**
  * Check if there is an exception and print if it is the case
  * @param errorMsg the error message which will be displayed if an exception is catched 
  * @return 
  */
-BOOL catchIfJavaException(char *errorMsg);
+JVM_IMPEXP BOOL catchIfJavaException(char *errorMsg);
 
 #endif /* __CATCHIFJAVAEXCEPTION_H__*/
 /*--------------------------------------------------------------------------*/
