@@ -27,34 +27,40 @@
 #include "stack-c.h"
 #include "callFunctionFromGateway.h"
 /*--------------------------------------------------------------------------*/
-static gw_generic_table Tab[]={
-{C2F(sci_var2vec),"var2vec"},
-{C2F(sci_vec2var),"vec2var"},
-{C2F(sci_getblocklabel),"getblocklabel"},
-{C2F(sci_scicos_debug),"scicos_debug"},
-{C2F(sci_scicos_debug_count),"scicos_debug_count"},
-{C2F(sci_sctree),"sctree"},
-{C2F(sci_sci_tree2),"sci_tree2"},
-{C2F(sci_sci_tree3),"sci_tree3"},
-{C2F(sci_sci_tree4),"sci_tree4"},
-{C2F(sci_curblock),"curblock"},
-{C2F(sci_scicos_time),"scicos_time"},
-{C2F(sci_duplicate),"duplicate"},
-{C2F(sci_diffobjs),"diffobjs"},
-{C2F(sci_pointer_xproperty),"pointer_xproperty"},
-{C2F(sci_phase_simulation),"phase_simulation"},
-{C2F(sci_set_xproperty),"set_xproperty"},
-{C2F(sci_set_blockerror),"set_blockerror"},
-{C2F(sci_ctree2),"ctree2"},
-{C2F(sci_ctree3),"ctree3"},
-{C2F(sci_ctree4),"ctree4"},
-{C2F(sci_scicosim),"scicosim"},
-{C2F(sci_getscicosvars),"getscicosvars"},
-{C2F(sci_curblockc),"curblockc"},
-{C2F(sci_buildouttb),"buildouttb"},
-{C2F(sci_permutobj),"permutobj"},
-{C2F(sci_end_scicosim),"end_scicosim"},
-{sci_haltscicos, "sci_haltscicos"},
+static gw_generic_table Tab[] = 
+{
+	{sci_var2vec,"var2vec"},
+	{sci_vec2var,"vec2var"},
+	{sci_getblocklabel,"getblocklabel"},
+	{sci_scicos_debug,"scicos_debug"},
+	{sci_scicos_debug_count,"scicos_debug_count"},
+	{sci_sctree,"sctree"},
+	{sci_ftree2,"sci_tree2"},
+	{sci_ftree3,"sci_tree3"},
+	{sci_ftree4,"sci_tree4"},
+	{sci_curblock,"curblock"},
+	{sci_scicos_time,"scicos_time"},
+	{sci_duplicate,"duplicate"},
+	{sci_diffobjs,"diffobjs"},
+	{sci_pointer_xproperty,"pointer_xproperty"},
+	{sci_phase_simulation,"phase_simulation"},
+	{sci_set_xproperty,"set_xproperty"},
+	{sci_set_blockerror,"set_blockerror"},
+	{sci_ctree2,"ctree2"},
+	{sci_ctree3,"ctree3"},
+	{sci_ctree4,"ctree4"},
+	{sci_scicosim,"scicosim"},
+	{sci_getscicosvars,"getscicosvars"},
+	{sci_curblockc,"curblockc"},
+	{sci_buildouttb,"buildouttb"},
+	{sci_permutobj,"permutobj"},
+	{sci_end_scicosim,"end_scicosim"},
+	{sci_coserror, "coserror"},
+	{sci_haltscicos, "sci_haltscicos"},
+	{sci_data2sig,"data2sig"},
+	{sci_sig2data,"sig2data"},
+	{sci_model2blk,"model2blk"},
+	{sci_callblk,"callblk"}
 };
 /*--------------------------------------------------------------------------*/
 int gw_scicos(void)
