@@ -9,16 +9,31 @@
  * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
  *
  */
-
-#include "gw_special_functions1.h"
-#include "stack-c.h"
 #include <string.h>
+#include "gw_special_functions.h"
+#include "machine.h"
+#include "warningmode.h"
+#include "localization.h"
+#include "sciprint.h"
 /*--------------------------------------------------------------------------*/
 extern int C2F(intsbesselk)(char *id,unsigned long fname_len);
 /*--------------------------------------------------------------------------*/
-int C2F(sci_oldbesselk)(char *fname,unsigned long fname_len)
+int sci_oldbesselk(char *fname,unsigned long fname_len)
 {
-	C2F(intsbesselk)(fname,fname_len);
-	return 0;
+    if (getWarningMode())
+    {
+        sciprint(_("Warning: "));
+        sciprint(_("Function %s is obsolete."), fname);
+        sciprint("\n");
+        sciprint(_("Warning: "));
+        sciprint(_("Please use %s instead."), "besselk");
+        sciprint("\n");
+        sciprint(_("Warning: "));
+        sciprint(_("This function will be permanently removed in Scilab %s"), "5.3.1");
+        sciprint("\n");
+    }
+
+    C2F(intsbesselk)(fname,fname_len);
+    return 0;
 }
 /*--------------------------------------------------------------------------*/
