@@ -14,7 +14,7 @@
 
 /*--------------------------------------------------------------------------*/
 #include <string.h>
-#include <ctype.h>
+#include <wctype.h>
 #include "isalphanum.h"
 #include "MALLOC.h"
 /*--------------------------------------------------------------------------*/
