@@ -27,25 +27,25 @@ import org.scilab.modules.graph.ScilabGraph;
 import org.scilab.modules.graph.ScilabGraphUniqueObject;
 import org.scilab.modules.graph.actions.base.VertexSelectionDependantAction;
 import org.scilab.modules.gui.menuitem.MenuItem;
-import org.scilab.modules.hdf5.scilabTypes.ScilabDouble;
-import org.scilab.modules.hdf5.scilabTypes.ScilabList;
-import org.scilab.modules.hdf5.scilabTypes.ScilabString;
+import org.scilab.modules.types.ScilabDouble;
+import org.scilab.modules.types.ScilabList;
+import org.scilab.modules.types.ScilabString;
 import org.scilab.modules.xcos.block.BasicBlock;
 import org.scilab.modules.xcos.block.BlockFactory;
 import org.scilab.modules.xcos.block.SplitBlock;
 import org.scilab.modules.xcos.block.SuperBlock;
 import org.scilab.modules.xcos.block.io.ContextUpdate;
+import org.scilab.modules.xcos.block.io.ContextUpdate.IOBlocks;
 import org.scilab.modules.xcos.block.io.EventInBlock;
 import org.scilab.modules.xcos.block.io.EventOutBlock;
 import org.scilab.modules.xcos.block.io.ExplicitInBlock;
 import org.scilab.modules.xcos.block.io.ExplicitOutBlock;
 import org.scilab.modules.xcos.block.io.ImplicitInBlock;
 import org.scilab.modules.xcos.block.io.ImplicitOutBlock;
-import org.scilab.modules.xcos.block.io.ContextUpdate.IOBlocks;
 import org.scilab.modules.xcos.graph.SuperBlockDiagram;
 import org.scilab.modules.xcos.graph.XcosDiagram;
-import org.scilab.modules.xcos.io.BasicBlockInfo;
-import org.scilab.modules.xcos.io.BlockWriter;
+import org.scilab.modules.xcos.io.scicos.BasicBlockInfo;
+import org.scilab.modules.xcos.io.scicos.DiagramElement;
 import org.scilab.modules.xcos.link.BasicLink;
 import org.scilab.modules.xcos.link.commandcontrol.CommandControlLink;
 import org.scilab.modules.xcos.link.explicit.ExplicitLink;
@@ -64,27 +64,29 @@ import org.scilab.modules.xcos.utils.XcosMessages;
 import com.mxgraph.model.mxGeometry;
 
 /**
- * Transform selection to a new superblock.
+ * Extract the selection to a new diagram and create a {@link SuperBlock} which
+ * contains this new diagram.
  */
 public final class RegionToSuperblockAction extends VertexSelectionDependantAction {
 	/** Name of the action */
 	public static final String NAME = XcosMessages.REGION_TO_SUPERBLOCK;
 	/** Icon name of the action */
-	public static final String SMALL_ICON = "";
+	public static final String SMALL_ICON = "object-group.png";
 	/** Mnemonic key of the action */
 	public static final int MNEMONIC_KEY = 0;
 	/** Accelerator key for the action */
 	public static final int ACCELERATOR_KEY = 0;
 	
-    /**
-     * @author Antoine ELIAS
-     *
-     */
-    private class BrokenLink {
-	private BasicLink link;
-	private BasicPort port;
-	private mxGeometry geom;
-	private boolean outGoing;
+	private static final String INTERFUNCTION_NAME = "SUPER_f";
+
+	/**
+	 * Any link which is broken by performing this action
+	 */
+    private static class BrokenLink {
+	private final BasicLink link;
+	private final BasicPort port;
+	private final mxGeometry geom;
+	private final boolean outGoing;
 	private int portNumber;
 
 	/**
@@ -213,17 +215,16 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	/*
 	 * Creating the superblock
 	 */
-	SuperBlock superBlock = (SuperBlock) BlockFactory.createBlock("SUPER_f");
-	superBlock.setStyle("SUPER_f");
+	SuperBlock superBlock = (SuperBlock) BlockFactory.createBlock(INTERFUNCTION_NAME);
+	superBlock.setStyle(INTERFUNCTION_NAME);
 	superBlock.getGeometry().setX((maxX + minX) / 2.0);
 	superBlock.getGeometry().setY((maxY + minY) / 2.0);
 
-
-
 	/*
 	 * Creating the child graph
 	 */
 	SuperBlockDiagram diagram = new SuperBlockDiagram(superBlock);
+	diagram.installListeners();
 
 	diagram.getModel().beginUpdate();
 	diagram.addCells(cellsCopy.toArray());
@@ -245,7 +246,8 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	/*
 	 * Update block with real parameters
 	 */
-	superBlock.setRealParameters(BlockWriter.convertDiagramToMList(diagram));
+	superBlock.setRealParameters(new DiagramElement().encode(diagram));
+	diagram.installSuperBlockListeners();
 	superBlock.setChild(diagram);
 	
 	/*
@@ -273,8 +275,8 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	 */
 	int midBlockIndex = blocksCopyWithoutSplitBlocks.size() / 2;
 	superBlock.setAngle(BlockPositioning.roundAngle(angle / blocksCopyWithoutSplitBlocks.size()));
-	superBlock.setFlip((flipped > midBlockIndex) ? true : false);
-	superBlock.setMirror((mirrored > midBlockIndex) ? true : false);
+	superBlock.setFlip(flipped > midBlockIndex);
+	superBlock.setMirror(mirrored > midBlockIndex);
 	
 	/*
 	 * Update the view
@@ -330,28 +332,7 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 		    if (block.getChildAt(j) instanceof BasicPort) {
 			BasicPort port = (BasicPort) block.getChildAt(j);
 			if (port.getEdgeCount() > 0) {
-			    if (port.getEdgeAt(0) instanceof BasicLink) {
-				BasicLink link = (BasicLink) port.getEdgeAt(0);
-				BasicBlock otherSide = null;
-				if (link.getTarget() == port) {
-				    otherSide = (BasicBlock) link.getSource()
-					    .getParent();
-				} else {
-				    otherSide = (BasicBlock) link.getTarget()
-					    .getParent();
-				} // target == port
-
-				if (isInSelection(graph.getSelectionCells(), otherSide)) {
-				    graph.addSelectionCell(link);
-				} else {
-					graph.removeSelectionCell(link);
-				}
-				
-				if (otherSide instanceof SplitBlock) {
-				    graph.addSelectionCell(otherSide);
-				} // otherSide is a SplitBlock
-
-			    } // BasicLink
+			    selectOtherSide(graph, port);
 			} // Edge > 0
 		    } // BasicPort
 		} // for child
@@ -374,6 +355,35 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	
 	return new ArrayList<ScilabGraphUniqueObject>(Arrays.asList(typedCells));
     }
+
+	/**
+	 * @param graph the parent graph
+	 * @param port The port we are working on
+	 */
+	private void selectOtherSide(XcosDiagram graph, BasicPort port) {
+		if (port.getEdgeAt(0) instanceof BasicLink) {
+		BasicLink link = (BasicLink) port.getEdgeAt(0);
+		BasicBlock otherSide = null;
+		if (link.getTarget() == port) {
+		    otherSide = (BasicBlock) link.getSource()
+			    .getParent();
+		} else {
+		    otherSide = (BasicBlock) link.getTarget()
+			    .getParent();
+		} // target == port
+
+		if (isInSelection(graph.getSelectionCells(), otherSide)) {
+		    graph.addSelectionCell(link);
+		} else {
+			graph.removeSelectionCell(link);
+		}
+
+		if (otherSide instanceof SplitBlock) {
+		    graph.addSelectionCell(otherSide);
+		} // otherSide is a SplitBlock
+
+		} // BasicLink
+	}
     
     /**
      * Re-link the parent Graph
@@ -395,21 +405,21 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	    	target = (BasicPort) link.getLink().getTarget();
 
 	    	if (link.getLink() instanceof ExplicitLink) {
-	    		source = BasicBlockInfo.getAllExplicitOutputPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		source = BasicBlockInfo.getAllTypedPorts(superBlock, false, ExplicitOutputPort.class).get(link.getPortNumber() - 1);
 	    	} else if (link.getLink() instanceof ImplicitLink) {
-	    		source = BasicBlockInfo.getAllImplicitOutputPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		source = BasicBlockInfo.getAllTypedPorts(superBlock, false, ImplicitOutputPort.class).get(link.getPortNumber() - 1);
 	    	} else if (link.getLink() instanceof CommandControlLink) {
-	    		source = BasicBlockInfo.getAllCommandPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		source = BasicBlockInfo.getAllTypedPorts(superBlock, false, CommandPort.class).get(link.getPortNumber() - 1);
 	    	}
 	    } else {
 	    	source = (BasicPort) link.getLink().getSource();
 
 	    	if (link.getLink() instanceof ExplicitLink) {
-	    		target = BasicBlockInfo.getAllExplicitInputPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		target = BasicBlockInfo.getAllTypedPorts(superBlock, false, ExplicitInputPort.class).get(link.getPortNumber() - 1);
 	    	} else if (link.getLink() instanceof ImplicitLink) {
-	    		target = BasicBlockInfo.getAllImplicitInputPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		target = BasicBlockInfo.getAllTypedPorts(superBlock, false, ImplicitInputPort.class).get(link.getPortNumber() - 1);
 	    	} else if (link.getLink() instanceof CommandControlLink) {
-	    		target = BasicBlockInfo.getAllControlPorts(superBlock, false).get(link.getPortNumber() - 1);
+	    		target = BasicBlockInfo.getAllTypedPorts(superBlock, false, ControlPort.class).get(link.getPortNumber() - 1);
 	    	}
 	    }
 
@@ -455,14 +465,12 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 		if (link.getOutGoing()) { // OUT_f
 		    block = BlockFactory.createBlock("OUT_f");
 		    ExplicitInputPort port = new ExplicitInputPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(0) + 1);
 		    maxValues.set(0, maxValues.get(0) + 1);
 		} else { // IN_f
 		    block = BlockFactory.createBlock("IN_f");
 		    ExplicitOutputPort port = new ExplicitOutputPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(1) + 1);
 		    maxValues.set(1, maxValues.get(1) + 1);
@@ -471,14 +479,12 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 		if (link.getOutGoing()) { // OUTIMPL_f
 		    block = BlockFactory.createBlock("OUTIMPL_f");
 		    ImplicitInputPort port = new ImplicitInputPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(2) + 1);
 		    maxValues.set(2, maxValues.get(2) + 1);
 		} else { // INIMPL_f
 		    block = BlockFactory.createBlock("INIMPL_f");
 		    ImplicitOutputPort port = new ImplicitOutputPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(3) + 1);
 		    maxValues.set(3, maxValues.get(3) + 1);
@@ -487,20 +493,22 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 		if (link.getOutGoing()) { // CLKOUTV_f
 		    block = BlockFactory.createBlock("CLKOUTV_f");
 		    ControlPort port = new ControlPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(4) + 1);
 		    maxValues.set(4, maxValues.get(4) + 1);
 		} else { // CLKINV_f
 		    block = BlockFactory.createBlock("CLKINV_f");
 		    CommandPort port = new CommandPort();
-		    port.setDefaultValues();
 		    block.addPort(port);
 		    link.setPortNumber(maxValues.get(5) + 1);
 		    maxValues.set(5, maxValues.get(5) + 1);
 		}
 	    }
 
+		/**
+		 * FIXME: findbugs found that some execution path may lead to a
+		 * NullPointerException on the next line.
+		 */
 	    block.setGeometry(link.getGeometry());
 	    block.setExprs(new ScilabString(Integer.toString(link
 		    .getPortNumber())));
@@ -512,6 +520,8 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	    diagram.addCells(new Object[] {block});
 	    diagram.getModel().endUpdate();
 
+	    BlockPositioning.updateBlockView(block);
+	    
 	    /*
 	     * create new link in SuperBlock
 	     */
@@ -521,14 +531,14 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 			.createLinkFromPorts((BasicPort) link.getLink()
 				.getSource(), (BasicPort) block.getChildAt(0));
 		newLink.setGeometry(link.getLink().getGeometry());
-		newLink.setSource((BasicPort) link.getPort());
-		newLink.setTarget((BasicPort) block.getChildAt(0));
+		newLink.setSource(link.getPort());
+		newLink.setTarget(block.getChildAt(0));
 	    } else { // new -> old
 		newLink = BasicLink.createLinkFromPorts((BasicPort) block
 			.getChildAt(0), (BasicPort) link.getLink().getTarget());
 		newLink.setGeometry(link.getLink().getGeometry());
-		newLink.setSource((BasicPort) block.getChildAt(0));
-		newLink.setTarget((BasicPort) link.getPort());
+		newLink.setSource(block.getChildAt(0));
+		newLink.setTarget(link.getPort());
 	    }
 
 	    diagram.getModel().beginUpdate();
@@ -552,25 +562,27 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	    if (objs.get(i) instanceof BasicBlock) {
 		BasicBlock block = (BasicBlock) objs.get(i);
 		for (int j = 0; j < block.getChildCount(); j++) {
-		    BasicPort port = (BasicPort) block.getChildAt(j);
-		    if (port.getEdgeCount() != 0) {
-			BasicLink link = (BasicLink) port.getEdgeAt(0);
-			if (block.getChildAt(j) instanceof InputPort
-				|| block.getChildAt(j) instanceof ControlPort) {
-			    BasicBlock source = (BasicBlock) (link.getSource()
-				    .getParent());
-			    if (!objs.contains(source)) {
-				BasicPort copiedPort = (BasicPort) ((BasicBlock) copiedCells.get(i)).getChildAt(j);
-				breaks.add(new BrokenLink(link, copiedPort, source.getGeometry(), false));
-			    }
-			} else { // OutputPort or CommandPort
-			    BasicBlock target = (BasicBlock) (link.getTarget().getParent());
-			    if (!objs.contains(target)) {
-				BasicPort copiedPort = (BasicPort) ((BasicBlock) copiedCells.get(i)).getChildAt(j);
-				breaks.add(new BrokenLink(link, copiedPort, target.getGeometry(), true));
+			if (block.getChildAt(j) instanceof BasicPort) {
+			    BasicPort port = (BasicPort) block.getChildAt(j);
+			    if (port.getEdgeCount() != 0) {
+				BasicLink link = (BasicLink) port.getEdgeAt(0);
+				if (block.getChildAt(j) instanceof InputPort
+					|| block.getChildAt(j) instanceof ControlPort) {
+				    BasicBlock source = (BasicBlock) (link.getSource()
+					    .getParent());
+				    if (!objs.contains(source)) {
+					BasicPort copiedPort = (BasicPort) ((BasicBlock) copiedCells.get(i)).getChildAt(j);
+					breaks.add(new BrokenLink(link, copiedPort, source.getGeometry(), false));
+				    }
+				} else { // OutputPort or CommandPort
+				    BasicBlock target = (BasicBlock) (link.getTarget().getParent());
+				    if (!objs.contains(target)) {
+					BasicPort copiedPort = (BasicPort) ((BasicBlock) copiedCells.get(i)).getChildAt(j);
+					breaks.add(new BrokenLink(link, copiedPort, target.getGeometry(), true));
+				    }
+				}
 			    }
 			}
-		    }
 		}
 	    }
 	}
@@ -587,19 +599,6 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	return Arrays.asList(objs).contains(item);
     }
 
-    /**
-     * @param breaks List of broken link in current selection
-     */
-    private void printBreakingLink(List<BrokenLink> breaks) {
-	System.err.println("breaks count : " + breaks.size());
-
-	for (BrokenLink brk : breaks) {
-	    System.err.println("Link : " + brk.getLink());
-	    System.err.println("OutGoing : " + brk.getOutGoing());
-	    System.err.println("Geometry : " + brk.getGeometry());
-	}
-    }
-
     /**
      * @param blocks list of blocks
      * @return integer list of max values
@@ -612,7 +611,7 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	for (ScilabGraphUniqueObject cell : blocks) {
 	    if (cell instanceof ContextUpdate) {
 	    if (cell instanceof ExplicitOutBlock) {
-		if (!items.containsKey(IOBlocks.ExplicitInBlock)) {
+		if (!items.containsKey(IOBlocks.ExplicitOutBlock)) {
 		    items.put(IOBlocks.ExplicitOutBlock, new ArrayList<BasicBlock>());
 		}
 		items.get(IOBlocks.ExplicitOutBlock).add((BasicBlock) cell);
@@ -660,9 +659,9 @@ public final class RegionToSuperblockAction extends VertexSelectionDependantActi
 	int maxValue = 0;
 	if (blocks != null) {
 	    for (int i = 0; i < blocks.size(); i++) {
-		if (((BasicBlock) blocks.get(i)).getExprs() instanceof ScilabString) {
+		if ((blocks.get(i)).getExprs() instanceof ScilabString) {
 		    maxValue = Math.max(maxValue, Integer
-			    .parseInt(((ScilabString) ((BasicBlock) blocks
+			    .parseInt(((ScilabString) (blocks
 				    .get(i)).getExprs()).getData()[0][0]));
 		}
 	    }
