@@ -14,15 +14,22 @@ package org.scilab.modules.xcos.io.codec;
 
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.scilab.modules.graph.utils.StyleMap;
 import org.scilab.modules.xcos.block.BasicBlock;
 import org.scilab.modules.xcos.block.BasicBlock.SimulationFunctionType;
+import org.scilab.modules.xcos.block.BlockFactory;
+import org.scilab.modules.xcos.block.BlockFactory.BlockInterFunction;
+import org.scilab.modules.xcos.block.SuperBlock;
 import org.scilab.modules.xcos.io.XcosObjectCodec;
 import org.w3c.dom.Element;
 import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
 
+import com.mxgraph.io.mxCellCodec;
 import com.mxgraph.io.mxCodec;
+import com.mxgraph.io.mxCodecRegistry;
 import com.mxgraph.model.mxCell;
 
 /**
@@ -31,6 +38,8 @@ import com.mxgraph.model.mxCell;
 public class BasicBlockCodec extends XcosObjectCodec {
 
 	private static final String SIMULATION_FUNCTION_TYPE = "simulationFunctionType";
+	private static final String[] IGNORED_FIELDS = new String[] {SIMULATION_FUNCTION_TYPE, "locked", "parametersPCS"};
+	private static final Log LOG = LogFactory.getLog(BasicBlockCodec.class);
 
 	/**
 	 * The constructor used on for configuration
@@ -42,7 +51,36 @@ public class BasicBlockCodec extends XcosObjectCodec {
 	public BasicBlockCodec(Object template, String[] exclude, String[] idrefs, Map<String, String> mapping)
 	{
 		super(template, exclude, idrefs, mapping);
-
+	}
+	
+	/**
+	 * Register all known codecs on the {@link mxCodecRegistry}.
+	 */
+	public static void register() {
+		mxCodecRegistry.addPackage("org.scilab.modules.xcos.block");
+		mxCodecRegistry.addPackage("org.scilab.modules.xcos.block.io");
+		mxCodecRegistry.addPackage("org.scilab.modules.xcos.block.positionning");
+		
+		for (BlockInterFunction function : BlockFactory.BlockInterFunction.values()) {
+			XcosObjectCodec codec = new BasicBlockCodec(function.getSharedInstance(),
+					IGNORED_FIELDS, REFS, null);
+			mxCodecRegistry.register(codec);
+		}
+		
+		XcosObjectCodec basicBlockCodec = new BasicBlockCodec(new BasicBlock(),
+				IGNORED_FIELDS, REFS, null);
+		mxCodecRegistry.register(basicBlockCodec);
+		
+		mxCellCodec cellCodec = new mxCellCodec(new mxCell(), null,
+				REFS, null);
+		mxCodecRegistry.register(cellCodec);
+		
+		/*
+		 * per block specific codec setup 
+		 */
+		BasicBlockCodec codec = (BasicBlockCodec) mxCodecRegistry.getCodec("AfficheBlock");
+		codec.exclude.add("printTimer");
+		codec.exclude.add("updateAction");
 	}
 	
 	/**
@@ -53,6 +91,7 @@ public class BasicBlockCodec extends XcosObjectCodec {
 	 * @return Returns the object to be encoded by the default encoding.
 	 * @see com.mxgraph.io.mxObjectCodec#beforeEncode(com.mxgraph.io.mxCodec, java.lang.Object, org.w3c.dom.Node)
 	 */
+	@Override
 	public Object beforeEncode(mxCodec enc, Object obj, Node node) {
 		((Element) node).setAttribute(SIMULATION_FUNCTION_TYPE,
 				String.valueOf(((BasicBlock) obj).getSimulationFunctionType()));
@@ -67,7 +106,13 @@ public class BasicBlockCodec extends XcosObjectCodec {
 	 * @return The Object transformed 
 	 * @see org.scilab.modules.xcos.io.XcosObjectCodec#afterDecode(com.mxgraph.io.mxCodec, org.w3c.dom.Node, java.lang.Object)
 	 */
+	@Override
 	public Object afterDecode(mxCodec dec, Node node, Object obj) {
+		if (!(obj instanceof BasicBlock)) {
+			LOG.error("Unable to decode " + obj);
+			return obj;
+		}
+		
 	    ((BasicBlock) obj).setSimulationFunctionType(SimulationFunctionType.DEFAULT);
 
 	    String functionType = (((Element) node).getAttribute(SIMULATION_FUNCTION_TYPE));
@@ -86,6 +131,14 @@ public class BasicBlockCodec extends XcosObjectCodec {
 		}
 	    }
 
+	    // Re associate the diagram container
+	    if (obj instanceof SuperBlock) {
+	    	final SuperBlock block = (SuperBlock) obj;
+	    	if (block.getChild() != null) {
+	    		block.getChild().setContainer(block);
+	    	}
+	    }
+	    
 	    // update style to replace direction by rotation and add the 
 	    // default style if absent
 	    StyleMap map = new StyleMap(((Element) node).getAttribute(STYLE));
@@ -112,6 +165,11 @@ public class BasicBlockCodec extends XcosObjectCodec {
 		// Remove the abstract blockWithLabel (set as defaultVertex) 
 		map.remove("blockWithLabel");
 		
+		// Remove a custom shape value
+		// This is used for pre-5.2 schema with TEXT_f block with a custom
+		// "shape=label" style attribute.
+		map.remove("shape");
+		
 		formatStyle(map);
 	}
 }
